Welcome to Fiona’s documentation! — Fiona 1.0 documentation

### Navigation

- index
- next |
- Fiona 1.0 documentation »

# Welcome to Fiona’s documentation!

Contents:

- README
  - Dependencies
  - Installation
  - Usage
  - Development and testing
  - Credits
- 1 The Fiona User Manual
  - 1.1 Introduction
  - 1.2 Reading and Writing Data

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Fiona 1.0 documentation »